# Security Policy

## Supported Versions

The following versions of xbbg are currently being supported with security updates:

| Version | Supported          |
| ------- | ------------------ |
| 0.7.x   | :white_check_mark: |
| < 0.7   | :x:                |

We support the latest minor version (0.7.x) with security updates. Older versions may receive critical security patches on a case-by-case basis.

## Reporting a Vulnerability

If you discover a security vulnerability in xbbg, please report it responsibly:

1. **Do not** open a public GitHub issue for security vulnerabilities
2. Contact the maintainer through a private channel
3. Include a detailed description of the vulnerability
4. Include steps to reproduce the issue (if applicable)

### What to Expect

- We'll do our best to respond and address security issues in a timely manner
- We'll keep you updated on the progress of any fixes
